#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2011  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# enable python3 by default
%bcond_without python3

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif


Name:		qubes-gpg-split-dom0
Version:	2.0.51
Release:	1%{dist}
Summary:    Qubes policy for gpg split

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires: make
%if %{with python2}
BuildRequires: python-setuptools
BuildRequires: python2-rpm-macros
%endif
%if %{with python3}
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-devel
%endif
Requires:	gpg

Source0: qubes-gpg-split-%{version}.tar.gz

%description

%prep
%setup -q -n qubes-gpg-split-%{version}

%install
rm -rf $RPM_BUILD_ROOT
install -m 0664 -D qubes.Gpg.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.Gpg
install -m 0664 -D qubes.GpgImportKey.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.GpgImportKey
%{?with_python2:make -C tests install-dom0-py2 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python2}}
%{?with_python3:make -C tests install-dom0-py3 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python3}}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.Gpg
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.GpgImportKey
%if %{with python2}
%dir %{python2_sitelib}/splitgpg-*.egg-info
%{python2_sitelib}/splitgpg-*.egg-info/*
%{python2_sitelib}/splitgpg
%endif
%if %{with python3}
%dir %{python3_sitelib}/splitgpg-*.egg-info
%{python3_sitelib}/splitgpg-*.egg-info/*
%{python3_sitelib}/splitgpg
%endif

%changelog
* Fri Aug 06 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-app-linux-split-gpg.git

* Fri Aug 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9e8baea
- version 2.0.51

* Fri Jul 30 2021 deeplow <deeplower@protonmail.com> - e086143
- test: fix missed clicks on "open file" dialogue

* Wed Jul 28 2021 deeplow <deeplower@protonmail.com> - 4eddc75
- tests: generate w/ subkeys in remaining tests

* Thu Jul 15 2021 deeplow <deeplower@protonmail.com> - 8ee3294
- tests: master key sign-only + subkey

* Sat May 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - eae1af1
- spec: add BR make

* Tue Dec 08 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aa5f3dc
- version 2.0.50

* Sun Dec 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2d3a092
- tests: adjust key import dialog in debian-10

* Wed Dec 02 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - edc6a64
- Allow to override defined CFLAGS

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 225295b
- Add .gitlab-ci.yml

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 025ee29
- Improve reproducibility

* Fri Nov 13 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6749b2f
- version 2.0.49

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5acd498
- tests: try to get the main TB window, not any splash screen

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4155887
- rpm: skip python3-dogtail on CentOS

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2056385
- Adjust tests for Debian 10

* Sat Oct 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 908700a
- version 2.0.48

* Wed Sep 30 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - fbe9d03
- tests: do show_menu_bar after skip_autoconf

* Tue Sep 29 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 42a02ed
- Fix tests for Thunderbird 68

* Tue Sep 29 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e174d5c
- tests: enhance behavior and increase action and default delays

* Tue Sep 29 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4bc201b
- test_thunderbird: handle thunderbird-78+

* Mon Sep 07 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6f54e6e
- test_thunderbird: make PEP8 happier

* Sun Aug 16 2020 Ludovic Bellier <lbellier-gth@zyrianes.net> - 32fcb66
- Fix tmpfiles.d using a directory link

* Sun Aug 09 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4a1be07
- spec: replace hardcoded python3

* Sun Jul 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7d20d22
- Update travis

* Sun Jul 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3ba18af
- Update makefile

* Tue Jun 16 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aa42215
- version 2.0.47

* Mon Jun 15 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 32f298b
- Ignore tty/display related options

* Fri Jun 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8ae7da6
- version 2.0.46

* Fri Jun 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b39e5d3
- Add --unwrap to allowed options

* Tue Feb 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 015d981
- version 2.0.45

* Mon Feb 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fbdce20
- Make qubes.GpgImportKey service a proper script

* Mon Feb 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 145ee4c
- rpm: do not drop executable bit from qubes.GpgImportKey service

* Sun Feb 02 2020 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - bea91f7
- Made split GPG permission question box nicer

* Tue Jan 28 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d185587
- version 2.0.44

* Wed Jan 22 2020 Abel Luck <abel@guardianproject.info> - d1b3dff
- Whitelist opts to get mozilla/sops compatibility

* Sat Jan 18 2020 Johanna Abrahamsson <johanna@assured.se> - 3dea318
- Accept --personal-{cipher,...}-preferences with option-argument

* Mon Jan 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 226ccec
- version 2.0.43

* Mon Jan 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3c5d52f
- Fix qrexec policy permission

* Mon Jan 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1299856
- travis: switch to fc31 dom0

* Mon Jan 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b9e804e
- Don't include python2 tests on new dom0 (based on >f28)

* Sat Dec 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6bf9ecd
- version 2.0.42

* Tue Dec 03 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3541562
- tests: improve handling compose window in TB 68

* Mon Oct 28 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 27d6a96
- version 2.0.41

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9295a5b
- travis: switch to bionic

* Thu Oct 10 2019 Johanna Abrahamsson <johanna@assured.se> - 890bc8c
- add ignore for --disable-dirmngr option

* Sat Oct 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - af6800e
- version 2.0.40

* Sat Oct 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4f389fc
- tests: give more time for the actual test

* Mon Sep 30 2019 w1k1n9cc <git@malbolge.de> - fee3fbb
- wrong identation

* Mon Sep 30 2019 w1k1n9cc <git@malbolge.de> - f522d67
- Git is great but not in that case ;-)

* Mon Sep 30 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 30327f2
- version 2.0.39

* Sun Sep 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 79f904d
- tests: accept "Qubes Attachments" addon

